@@ -584,108 +584,165 @@ sub test_overload {
 sub test_matches {
     my $self = shift;
 
-    my $obj1 = Exception::Base->new;
-    $self->assert_num_equals(1, $obj1->matches);
-    $self->assert_num_equals(1, $obj1->matches(undef));
-    $self->assert_num_equals(0, $obj1->matches(sub {/Unknown/}));
-    $self->assert_num_equals(0, $obj1->matches(qr/Unknown/));
-    $self->assert_num_equals(0, $obj1->matches(sub {/False/}));
-    $self->assert_num_equals(0, $obj1->matches(qr/False/));
-    $self->assert_num_equals(1, $obj1->matches({tag=>undef}));
-    $self->assert_num_equals(0, $obj1->matches({tag=>'false'}));
-    $self->assert_num_equals(1, $obj1->matches({tag=>['False', qr//, sub {}, undef]}));
-    $self->assert_num_equals(0, $obj1->matches({tag=>['False', qr//, sub {}]}));
-    $self->assert_num_equals(0, $obj1->matches({tag=>[]}));
-    $self->assert_num_equals(1, $obj1->matches({tag=>[undef]}));
-    $self->assert_num_equals(1, $obj1->matches({message=>undef}));
-    $self->assert_num_equals(0, $obj1->matches({message=>'false'}));
-    $self->assert_num_equals(0, $obj1->matches({message=>sub{/false/}}));
-    $self->assert_num_equals(0, $obj1->matches({message=>qr/false/}));
-    $self->assert_num_equals(0, $obj1->matches({message=>[]}));
-    $self->assert_num_equals(1, $obj1->matches({message=>[undef]}));
-    $self->assert_num_equals(1, $obj1->matches({message=>['False', qr//, sub {}, undef]}));
-    $self->assert_num_equals(0, $obj1->matches({message=>['False', qr//, sub {}]}));
-    $self->assert_num_equals(0, $obj1->matches({-isa=>'False'}));
-    $self->assert_num_equals(1, $obj1->matches({-isa=>'Exception::Base'}));
-    $self->assert_num_equals(0, $obj1->matches({-isa=>['False', 'False', 'False']}));
-    $self->assert_num_equals(1, $obj1->matches({-isa=>['False', 'Exception::Base', 'False']}));
-    $self->assert_num_equals(0, $obj1->matches({-has=>'False'}));
-    $self->assert_num_equals(1, $obj1->matches({-has=>'message'}));
-    $self->assert_num_equals(0, $obj1->matches({-has=>['False', 'False', 'False']}));
-    $self->assert_num_equals(1, $obj1->matches({-has=>['False', 'message', 'False']}));
-    $self->assert_num_equals(1, $obj1->matches({-default=>undef}));
-    $self->assert_num_equals(0, $obj1->matches({-default=>'false'}));
-    $self->assert_num_equals(0, $obj1->matches('False'));
-    $self->assert_num_equals(0, $obj1->matches('Exception::Base'));
-    $self->assert_num_equals(1, $obj1->matches(0));
-    $self->assert_num_equals(0, $obj1->matches(1));
-    $self->assert_num_equals(0, $obj1->matches(123));
-    $self->assert_num_equals(0, $obj1->matches(['False', 'False', 'False']));
-    $self->assert_num_equals(1, $obj1->matches(['False', 'Exception::Base', 'False']));
-    $self->assert_num_equals(0, $obj1->matches(\1));
+    {
+        my $obj = Exception::Base->new;
+        $self->assert_num_equals(1, $obj->matches);
+        $self->assert_num_equals(1, $obj->matches(undef));
+        $self->assert_num_equals(0, $obj->matches(sub {/Unknown/}));
+        $self->assert_num_equals(0, $obj->matches(qr/Unknown/));
+        $self->assert_num_equals(0, $obj->matches(sub {/False/}));
+        $self->assert_num_equals(0, $obj->matches(qr/False/));
+        $self->assert_num_equals(1, $obj->matches({tag=>undef}));
+        $self->assert_num_equals(0, $obj->matches({tag=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({tag=>['False', qr//, sub {}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({tag=>['False', qr//, sub {}]}));
+        $self->assert_num_equals(0, $obj->matches({tag=>[]}));
+        $self->assert_num_equals(1, $obj->matches({tag=>[undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>undef}));
+        $self->assert_num_equals(0, $obj->matches({message=>'false'}));
+        $self->assert_num_equals(0, $obj->matches({message=>sub{/false/}}));
+        $self->assert_num_equals(0, $obj->matches({message=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({message=>[]}));
+        $self->assert_num_equals(1, $obj->matches({message=>[undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr//, sub {}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({message=>['False', qr//, sub {}]}));
+        $self->assert_num_equals(0, $obj->matches({-isa=>'False'}));
+        $self->assert_num_equals(1, $obj->matches({-isa=>'Exception::Base'}));
+        $self->assert_num_equals(0, $obj->matches({-isa=>['False', 'False', 'False']}));
+        $self->assert_num_equals(1, $obj->matches({-isa=>['False', 'Exception::Base', 'False']}));
+        $self->assert_num_equals(0, $obj->matches({-has=>'False'}));
+        $self->assert_num_equals(1, $obj->matches({-has=>'message'}));
+        $self->assert_num_equals(0, $obj->matches({-has=>['False', 'False', 'False']}));
+        $self->assert_num_equals(1, $obj->matches({-has=>['False', 'message', 'False']}));
+        $self->assert_num_equals(1, $obj->matches({-default=>undef}));
+        $self->assert_num_equals(0, $obj->matches({-default=>'false'}));
+        $self->assert_num_equals(0, $obj->matches('False'));
+        $self->assert_num_equals(0, $obj->matches('Exception::Base'));
+        $self->assert_num_equals(1, $obj->matches(0));
+        $self->assert_num_equals(0, $obj->matches(1));
+        $self->assert_num_equals(0, $obj->matches(123));
+        $self->assert_num_equals(0, $obj->matches(['False', 'False', 'False']));
+        $self->assert_num_equals(1, $obj->matches(['False', 'Exception::Base', 'False']));
+        $self->assert_num_equals(0, $obj->matches(\1));
+    };
 
-    my $obj2 = Exception::Base->new(message=>'Message', value=>123);
-    $self->assert_num_equals(0, $obj2->matches(undef));
-    $self->assert_num_equals(1, $obj2->matches(sub {/Message/}));
-    $self->assert_num_equals(0, $obj2->matches(sub {/False/}));
-    $self->assert_num_equals(1, $obj2->matches(qr/Message/));
-    $self->assert_num_equals(0, $obj2->matches(qr/False/));
-    $self->assert_num_equals(1, $obj2->matches({value=>123}));
-    $self->assert_num_equals(0, $obj2->matches({value=>'false'}));
-    $self->assert_num_equals(1, $obj2->matches({value=>sub {/123/}}));
-    $self->assert_num_equals(1, $obj2->matches({value=>qr/123/}));
-    $self->assert_num_equals(0, $obj2->matches({value=>sub {/false/}}));
-    $self->assert_num_equals(0, $obj2->matches({value=>qr/false/}));
-    $self->assert_num_equals(0, $obj2->matches({value=>undef}));
-    $self->assert_num_equals(0, $obj2->matches({value=>[]}));
-    $self->assert_num_equals(0, $obj2->matches({value=>[undef]}));
-    $self->assert_num_equals(0, $obj2->matches({value=>['False', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({value=>['123', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({value=>['False', qr/123/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({value=>['False', qr/False/, sub {/123/}, undef]}));
-    $self->assert_num_equals(0, $obj2->matches({false=>'false'}));
-    $self->assert_num_equals(1, $obj2->matches({false=>undef}));
-    $self->assert_num_equals(1, $obj2->matches({message=>'Message', value=>123}));
-    $self->assert_num_equals(1, $obj2->matches({message=>sub {/Message/}, value=>sub {/123/}}));
-    $self->assert_num_equals(1, $obj2->matches({message=>qr/Message/, value=>qr/123/}));
-    $self->assert_num_equals(0, $obj2->matches({message=>undef}));
-    $self->assert_num_equals(1, $obj2->matches({message=>'Message'}));
-    $self->assert_num_equals(0, $obj2->matches({message=>'false'}));
-    $self->assert_num_equals(1, $obj2->matches({message=>sub{/Message/}}));
-    $self->assert_num_equals(1, $obj2->matches({message=>qr/Message/}));
-    $self->assert_num_equals(0, $obj2->matches({message=>sub{/false/}}));
-    $self->assert_num_equals(0, $obj2->matches({message=>qr/false/}));
-    $self->assert_num_equals(0, $obj2->matches({message=>[]}));
-    $self->assert_num_equals(0, $obj2->matches({message=>[undef]}));
-    $self->assert_num_equals(0, $obj2->matches({message=>['False', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({message=>['Message', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({message=>['False', qr/Message/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj2->matches({message=>['False', qr/False/, sub {/Message/}, undef]}));
-    $self->assert_num_equals(0, $obj2->matches({-default=>undef}));
-    $self->assert_num_equals(1, $obj2->matches({-default=>'Message'}));
-    $self->assert_num_equals(0, $obj2->matches('False'));
-    $self->assert_num_equals(0, $obj2->matches('Exception::Base'));
-    $self->assert_num_equals(1, $obj2->matches('Message'));
-    $self->assert_num_equals(0, $obj2->matches(0));
-    $self->assert_num_equals(0, $obj2->matches(1));
-    $self->assert_num_equals(1, $obj2->matches(123));
-    $self->assert_num_equals(0, $obj2->matches(['False', 'False', 'False']));
-    $self->assert_num_equals(1, $obj2->matches(['False', 'Exception::Base', 'False']));
-    $self->assert_num_equals(0, $obj2->matches(\1));
+    {
+        my $obj = Exception::Base->new(message=>'Message', value=>123);
+        $self->assert_num_equals(0, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches(sub {/Message/}));
+        $self->assert_num_equals(0, $obj->matches(sub {/False/}));
+        $self->assert_num_equals(1, $obj->matches(qr/Message/));
+        $self->assert_num_equals(0, $obj->matches(qr/False/));
+        $self->assert_num_equals(1, $obj->matches({value=>123}));
+        $self->assert_num_equals(0, $obj->matches({value=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({value=>sub {/123/}}));
+        $self->assert_num_equals(1, $obj->matches({value=>qr/123/}));
+        $self->assert_num_equals(0, $obj->matches({value=>sub {/false/}}));
+        $self->assert_num_equals(0, $obj->matches({value=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({value=>undef}));
+        $self->assert_num_equals(0, $obj->matches({value=>[]}));
+        $self->assert_num_equals(0, $obj->matches({value=>[undef]}));
+        $self->assert_num_equals(0, $obj->matches({value=>['False', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['123', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['False', qr/123/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['False', qr/False/, sub {/123/}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({false=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({false=>undef}));
+        $self->assert_num_equals(1, $obj->matches({message=>'Message', value=>123}));
+        $self->assert_num_equals(1, $obj->matches({message=>sub {/Message/}, value=>sub {/123/}}));
+        $self->assert_num_equals(1, $obj->matches({message=>qr/Message/, value=>qr/123/}));
+        $self->assert_num_equals(0, $obj->matches({message=>undef}));
+        $self->assert_num_equals(1, $obj->matches({message=>'Message'}));
+        $self->assert_num_equals(0, $obj->matches({message=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({message=>sub{/Message/}}));
+        $self->assert_num_equals(1, $obj->matches({message=>qr/Message/}));
+        $self->assert_num_equals(0, $obj->matches({message=>sub{/false/}}));
+        $self->assert_num_equals(0, $obj->matches({message=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({message=>[]}));
+        $self->assert_num_equals(0, $obj->matches({message=>[undef]}));
+        $self->assert_num_equals(0, $obj->matches({message=>['False', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['Message', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/Message/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/False/, sub {/Message/}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({-default=>undef}));
+        $self->assert_num_equals(1, $obj->matches({-default=>'Message'}));
+        $self->assert_num_equals(0, $obj->matches('False'));
+        $self->assert_num_equals(0, $obj->matches('Exception::Base'));
+        $self->assert_num_equals(1, $obj->matches('Message'));
+        $self->assert_num_equals(0, $obj->matches(0));
+        $self->assert_num_equals(0, $obj->matches(1));
+        $self->assert_num_equals(1, $obj->matches(123));
+        $self->assert_num_equals(0, $obj->matches(['False', 'False', 'False']));
+        $self->assert_num_equals(1, $obj->matches(['False', 'Exception::Base', 'False']));
+        $self->assert_num_equals(0, $obj->matches(\1));
+    };
 
-    my $obj3 = Exception::Base->new(message=>undef);
-    $self->assert_num_equals(1, $obj3->matches(undef));
-    $self->assert_num_equals(1, $obj3->matches({message=>undef}));
-    $self->assert_num_equals(0, $obj3->matches('false'));
-    $self->assert_num_equals(0, $obj3->matches({message=>'false'}));
-    $self->assert_num_equals(0, $obj3->matches({message=>sub {/false/}}));
-    $self->assert_num_equals(0, $obj3->matches({message=>qr/false/}));
-    $self->assert_num_equals(0, $obj3->matches({message=>[]}));
-    $self->assert_num_equals(1, $obj3->matches({message=>[undef]}));
-    $self->assert_num_equals(1, $obj3->matches({message=>['False', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj3->matches({message=>['Message', qr/False/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj3->matches({message=>['False', qr/Message/, sub {/False/}, undef]}));
-    $self->assert_num_equals(1, $obj3->matches({message=>['False', qr/False/, sub {/Message/}, undef]}));
+    {
+        my $obj = Exception::Base->new(message=>['%s', 'Message'], value=>123);
+        $self->assert_num_equals(0, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches(sub {/Message/}));
+        $self->assert_num_equals(0, $obj->matches(sub {/False/}));
+        $self->assert_num_equals(1, $obj->matches(qr/Message/));
+        $self->assert_num_equals(0, $obj->matches(qr/False/));
+        $self->assert_num_equals(1, $obj->matches({value=>123}));
+        $self->assert_num_equals(0, $obj->matches({value=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({value=>sub {/123/}}));
+        $self->assert_num_equals(1, $obj->matches({value=>qr/123/}));
+        $self->assert_num_equals(0, $obj->matches({value=>sub {/false/}}));
+        $self->assert_num_equals(0, $obj->matches({value=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({value=>undef}));
+        $self->assert_num_equals(0, $obj->matches({value=>[]}));
+        $self->assert_num_equals(0, $obj->matches({value=>[undef]}));
+        $self->assert_num_equals(0, $obj->matches({value=>['False', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['123', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['False', qr/123/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({value=>['False', qr/False/, sub {/123/}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({false=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({false=>undef}));
+        $self->assert_num_equals(1, $obj->matches({message=>'Message', value=>123}));
+        $self->assert_num_equals(1, $obj->matches({message=>sub {/Message/}, value=>sub {/123/}}));
+        $self->assert_num_equals(1, $obj->matches({message=>qr/Message/, value=>qr/123/}));
+        $self->assert_num_equals(0, $obj->matches({message=>undef}));
+        $self->assert_num_equals(1, $obj->matches({message=>'Message'}));
+        $self->assert_num_equals(0, $obj->matches({message=>'false'}));
+        $self->assert_num_equals(1, $obj->matches({message=>sub{/Message/}}));
+        $self->assert_num_equals(1, $obj->matches({message=>qr/Message/}));
+        $self->assert_num_equals(0, $obj->matches({message=>sub{/false/}}));
+        $self->assert_num_equals(0, $obj->matches({message=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({message=>[]}));
+        $self->assert_num_equals(0, $obj->matches({message=>[undef]}));
+        $self->assert_num_equals(0, $obj->matches({message=>['False', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['Message', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/Message/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/False/, sub {/Message/}, undef]}));
+        $self->assert_num_equals(0, $obj->matches({-default=>undef}));
+        $self->assert_num_equals(1, $obj->matches({-default=>'Message'}));
+        $self->assert_num_equals(0, $obj->matches('False'));
+        $self->assert_num_equals(0, $obj->matches('Exception::Base'));
+        $self->assert_num_equals(1, $obj->matches('Message'));
+        $self->assert_num_equals(0, $obj->matches(0));
+        $self->assert_num_equals(0, $obj->matches(1));
+        $self->assert_num_equals(1, $obj->matches(123));
+        $self->assert_num_equals(0, $obj->matches(['False', 'False', 'False']));
+        $self->assert_num_equals(1, $obj->matches(['False', 'Exception::Base', 'False']));
+        $self->assert_num_equals(0, $obj->matches(\1));
+    };
+
+    {
+        my $obj = Exception::Base->new(message=>undef);
+        $self->assert_num_equals(1, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches({message=>undef}));
+        $self->assert_num_equals(0, $obj->matches('false'));
+        $self->assert_num_equals(0, $obj->matches({message=>'false'}));
+        $self->assert_num_equals(0, $obj->matches({message=>sub {/false/}}));
+        $self->assert_num_equals(0, $obj->matches({message=>qr/false/}));
+        $self->assert_num_equals(0, $obj->matches({message=>[]}));
+        $self->assert_num_equals(1, $obj->matches({message=>[undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['Message', qr/False/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/Message/, sub {/False/}, undef]}));
+        $self->assert_num_equals(1, $obj->matches({message=>['False', qr/False/, sub {/Message/}, undef]}));
+    };
 
     eval q{
         package Exception::BaseTest::matches::Package1;
@@ -700,23 +757,29 @@ sub test_matches {
     };
     $self->assert_equals('', $@);
 
-    my $obj4 = Exception::BaseTest::matches::Package1->new;
-    $self->assert_num_equals(1, $obj4->matches(undef));
-    $self->assert_num_equals(1, $obj4->matches(0));
+    {
+        my $obj = Exception::BaseTest::matches::Package1->new;
+        $self->assert_num_equals(1, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches(0));
+    };
 
-    my $obj5 = Exception::BaseTest::matches::Package1->new(message=>'Message', value=>123);
-    $self->assert_num_equals(0, $obj5->matches(undef));
-    $self->assert_num_equals(1, $obj5->matches('Message'));
-    $self->assert_num_equals(1, $obj5->matches(qr/Message/));
-    $self->assert_num_equals(1, $obj5->matches(sub{qr/Message/}));
-    $self->assert_num_equals(1, $obj5->matches(0));
+    {
+        my $obj = Exception::BaseTest::matches::Package1->new(message=>'Message', value=>123);
+        $self->assert_num_equals(0, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches('Message'));
+        $self->assert_num_equals(1, $obj->matches(qr/Message/));
+        $self->assert_num_equals(1, $obj->matches(sub{qr/Message/}));
+        $self->assert_num_equals(1, $obj->matches(0));
+    };
 
-    my $obj6 = Exception::BaseTest::matches::Package1->new(message=>'Message', strattr=>'String', value=>123, numattr=>456);
-    $self->assert_num_equals(0, $obj6->matches(undef));
-    $self->assert_num_equals(1, $obj6->matches('Message: String'));
-    $self->assert_num_equals(1, $obj6->matches(qr/Message: String/));
-    $self->assert_num_equals(1, $obj6->matches(sub{qr/Message: String/}));
-    $self->assert_num_equals(1, $obj6->matches(456));
+    {
+        my $obj = Exception::BaseTest::matches::Package1->new(message=>'Message', strattr=>'String', value=>123, numattr=>456);
+        $self->assert_num_equals(0, $obj->matches(undef));
+        $self->assert_num_equals(1, $obj->matches('Message: String'));
+        $self->assert_num_equals(1, $obj->matches(qr/Message: String/));
+        $self->assert_num_equals(1, $obj->matches(sub{qr/Message: String/}));
+        $self->assert_num_equals(1, $obj->matches(456));
+    };
 }
 
 sub test_catch {
